@@ -107,6 +107,22 @@ class JSONWebToken:
             raise self.InvalidAudience(self, audiences)
         return is_valid
 
+    def verify(self,
+        audience: list = None,
+        issuers: list = None,
+        scope: list = None,
+        raise_exception: bool = True
+    ) -> bool:
+        """Verify if the JWT is not expired, issued by a trusted party, and
+        contains the correct scope.
+        """
+        if audience is not None:
+            self.verify_audience(audience, raise_exception=raise_exception)
+        if issuers is not None:
+            self.verify_issuer(issuers, raise_exception=raise_exception)
+        if scope is not None:
+            self.verify_scopes(scope, raise_exception=raise_exception)
+
     def verify_expired(self, now=None, raise_exception=True):
         """Verifies that the JSON Web Token is not expired, based on the
         `exp` claim.
