@@ -13,15 +13,15 @@ class JOSEKeyResolver:
         """Resolves a decryption or public key using the header and
         optionally the payload of a JOSE object.
         """
-        if header.kid is not None:
-            raise NotImplementedError
+        if header.kid is None:
+            return crypto.get_secret_key()
         resolve = self.resolve_private_key\
             if (header['alg'] in const.SYMMETRIC_ALGORITHMS)\
             else self.resolve_public_key
         return await resolve(header, payload=payload)
 
     async def resolve_public_key(self, header, payload=None):
-        raise NotImplementedError
+        return crypto.trust.get(header.kid)
 
-    async def resolve_private_key(self, header, payload=None):
-        return crypto.get_secret_key()
+    async def resolve_private_key(self, header, payload=None): # pragma: no cover
+        return crypto.chain.get(header.kid)
